# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'
RSpec.describe Hermes::HousingRequestFolder, type: :model do
  
  let!(:user1) {create(:user)}
  let!(:user2) {create(:user)}
  let!(:user3) {create(:user)}
  let!(:entity) {create(:entity, siret: '00000000000001')}
  let!(:applicant1) do
    create(
      :applicant,
      user: user1,
      monthly_charges: {},
      main_employer_siret: entity.siret,
      amount_year_minus_two: 20000,
    )
  end
  let!(:applicant2) do
    create(
      :applicant,
      user: user2,
      monthly_charges: {},
      nationality: '3',
      main_employer_siret: entity.siret
    )
  end
  
  it 'has a valid factory' do
    expect(FactoryBot.build(:housing_request_folder)).to be_valid
  end
  
  let!(:housing_request1) do
    create(
      :housing_request,
      is_active: true,
      main_applicant: applicant1,
      entity_status: 'EN COURS DE SAISIE',
      seeked_departments: ['83'],
      coapplicants: [
        {rel_type: 'M', id: applicant2.id}
      ]
    )
  end

  let!(:nud) { create(:nud, unique_number: '000000000001', housing_request: housing_request1)}

  describe 'update hr => hrFolder update ' do
    
    it 'has 2 required_documents' do
      expect(housing_request1.housing_request_folder.required_document_ids.length).to eq(2)
    end
  end

  describe 'update hr => hrFolder update ' do
    before :each do
      housing_request1.backoffice_status = "COMPLETE"
      housing_request1.save
    end
  
    it 'has 2 required_documents' do
      expect(housing_request1.housing_request_folder.required_document_ids.length).to eq(2)
      expect(housing_request1.housing_request_folder.required_documents[1].status).to eq("Pièce validée")
      expect( housing_request1.request_status).to eq("COMPLETE")
    end

    it 'should be update entity_status (auto validation)' do
      expect(housing_request1.reload.entity_status).to eq('EN COURS')
    end
  end

  describe 'With entity manual validation' do
    let!(:user1) { create(:user) }
    let!(:user2) { create(:user) }
    let!(:entity) { create(:entity, auto_request_validation: false, siret: '00000000000001') }
    let!(:applicant1) { create(:applicant, user: user1, monthly_charges: {}, main_employer_siret: entity.siret, amount_year_minus_two: 20000, nationality: '1') }
    let!(:applicant2) { create(:applicant, user: user2, monthly_charges: {}, nationality: '3') }
    let!(:housing_request1) { create(:housing_request, 
      is_active: true, 
      main_applicant: applicant1, 
      entity_status: 'EN COURS DE SAISIE', 
      seeked_departments: ['82'],
      coapplicants:[
        {rel_type: 'M', id: applicant2.id}
      ]
    ) }
    let!(:nud) { create(:nud, unique_number: '000000000001', housing_request: housing_request1)}
    before do
      housing_request1.backoffice_status = "COMPLETE"
      housing_request1.save
    end
    
    it 'should be update entity_status (manual validation)' do
      expect(housing_request1.reload.entity_status).to eq('A VALIDER')
    end
  end

  describe 'identity' do
    {
      "1": "Carte nationale d’identité ou passeport",
      "2": "Carte d'identité d'un pays européen",
      "3": "titre de séjour et Récépissé de renouvellement de titre de séjour si celui ci est expiré"
      
    }.each do |index, label|
      describe 'nationality= ' + index.to_s do
        before :each do
          applicant1.nationality = index.to_s
          applicant1.save
        end
        it 'has the good required document' do
          expect(housing_request1.reload.housing_request_folder.reload.required_document_ids.length).to eq(3)
          rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
          expect(rd.type).to eq(label)
        end
      end
    end
  end
  describe 'start_treatment' do

        before :each do
          applicant1.nationality = "1"
          applicant1.save
        end
        it 'has the good required document' do
          expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
          rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[1])
          rd.doc_id = 'ddd'
          rd.save
          housing_request1.reload.housing_request_folder.start_treatment
        end
  end
  describe 'identity' do
    {
      "1": "Carte nationale d’identité ou passeport",
      "2": "Carte d'identité d'un pays européen",
      "3": "titre de séjour et Récépissé de renouvellement de titre de séjour si celui ci est expiré"
  
    }.each do |index, label|
      describe 'nationality= ' + index.to_s do
        before :each do
          applicant1.nationality = index.to_s
          applicant1.save
        end
        it 'has the good required document' do
          expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
          rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
          expect(rd.type).to eq(label)
        end
      end
    end
  end
  describe 'dependents' do
    describe 'dependents= E G' do
      before :each do
        applicant1.nationality = nil
        applicant1.save
        housing_request1.dependents = [{
                                         'last_name' => 'GOUBILL',
                                         'first_name' => 'CHRIS',
                                         'birth_date' => '2017-03-23T00:00:00.000Z',
                                         'rel_type' => 'E',
                                         'coparentality' => 'G',
                                         'sex' => 'M'
                                       },
                                       {'last_name' => 'GOUBILL',
                                        'first_name' => 'CHRIsdS',
                                        'birth_date' => '1990-03-23T00:00:00.000Z',
                                        'rel_type' => 'E',
                                        'coparentality' => 'G',
                                        'sex' => 'M'},
                                       {'last_name' => 'GOUBILLze',
                                        'first_name' => 'CHRIS',
                                        'birth_date' => '2017-03-23T00:00:00.000Z',
                                        'rel_type' => 'P',
                                        'sex' => 'M'}]
        housing_request1.save
      end
      it 'has the good required document' do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(6)
      end
    end
    describe 'dependents= E G majeur' do
      before :each do
        applicant1.nationality = nil
        applicant1.save()
        housing_request1.dependents = [{"last_name" => "GOUBILL",
                                        "first_name" => "CHRIsdS",
                                        "birth_date" => "2002-03-16T00:00:00.000Z",
                                        "rel_type" => "E",
                                        "coparentality" => "G",
                                        "sex" => "M"},
        ]

        housing_request1.save
      end
      it 'has the good required document' do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(4)
      end
    end
    describe 'dependents= E G mineur' do
      before :each do
        applicant1.nationality = nil
        applicant1.save
        housing_request1.dependents = [{
                                         'last_name' => 'GOUBILL',
                                         'first_name' => 'CHRIS',
                                         'birth_date' => '2017-03-23T00:00:00.000Z',
                                         'rel_type' => 'E',
                                         'coparentality' => 'G',
                                         'sex' => 'M'
                                       }]
        housing_request1.save
      end
      it 'has the good required document' do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
      end
    end
  end
  
  describe 'unborn= 1' do
    before :each do
      applicant1.nationality = nil
      applicant1.save
      housing_request1.unborn_children = [{
                                            'anticipated_birth' => (Time.current + 10.days).to_s
                                          }]
      housing_request1.save
    end
    it 'has the good required document' do
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[2])
      expect(rd.type).to eq('Certificat de grossesse attestant que la grossesse est supérieure à 12 semaines')
    end
  end
  describe 'untensed_area' do
    let!(:untensed_area1) do
      create(
        :untensed_area,
        department: "33"
      )
    end
    let!(:untensed_area2) do
      create(
        :untensed_area,
        insee_code: "33201"
      )
    end
    before :each do
      applicant1.nationality = "1"
      applicant1.save
      housing_request1.unborn_children = [{
                                            'anticipated_birth' => '2020-03-23T00:00:00.000Z'
                                          }]
      housing_request1.seeked_localisation_list=[{"nom"=>"Paris",
                                                  "code"=>"33201",
                                                  "codesPostaux"=>['33201'],
                                                  'codeDepartement'=>'33',
                                                  "_score"=>1}]
      housing_request1.main_applicant.amount_year_minus_two = 2000
      housing_request1.main_applicant.save
      
      housing_request1.save
    end
    it 'has the good required document' do
      hrf = housing_request1.reload.housing_request_folder
      expect(hrf.get_labels.length).to eq 3
      expect(hrf.get_labels[2][:rf_consultation]).to eq true
     
    end
  end
  describe 'disabilities' do

      before :each do
        applicant1.nationality = nil
        applicant1.save
        housing_request1.disability_details = [{
                                         'disability_states' => 'GOUBILL',
                                         'birth_date' => '2017-03-23'
                                       },
                                      ]
        housing_request1.save
      end
      it 'has the good required document' do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
      end
    end

  describe 'PAV' do
  
    before :each do
      applicant1.nationality = nil

      applicant1.monthly_charges = {
                                               'PAV' => "200"
                                             } 
      applicant1.save
    end
    it 'has the good required document' do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
    end
  end

  
  describe 'ressources' do
    [
      {
        monthly_incomes: %w[AUT],
        required_documents: ['Justificatif(s) autres ressources perçues'],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[BE],
        required_documents: ["Carte d'étudiant délivrée par un établissement certifié et valable pour l'année en cours","Avis d'attribution de bourse"],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[RET],
        required_documents: ["Notification de pension"],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[PINV],
        required_documents: ['Attestation de la Caisse d’allocations familiales (CAF) /Mutualité sociale agricole (MSA)',],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[SAL],
        work_contract_type: %w[APP],
        required_documents: ["Contrat de travail de l'année en cours/ Bulletins de salaire du mois" +Hermes::HousingRequestFolder.new.get_month_label(-1),
                             "Contrat de travail de l'année en cours/ Bulletins de salaire du mois" +Hermes::HousingRequestFolder.new.get_month_label(-2),
                             "Contrat de travail de l'année en cours/ Bulletins de salaire du mois" +Hermes::HousingRequestFolder.new.get_month_label(-3),],
        r_for_consultation: true,
        r_for_application: true
      }, {
        monthly_incomes: %w[SAL],
        work_contract_type: %w[AUT],
        required_documents: ['justificatif(s) du salaire perçu'],
        r_for_consultation: true,
        r_for_application: true
      }, {
        monthly_incomes: %w[SAL],
        work_contract_type: %w[CDI CDD CDIP AGP],
        required_documents: ["Bulletin de salaire privé / public du mois " +Hermes::HousingRequestFolder.new.get_month_label(-1)+" ou Attestation de l'employeur",
                             "Bulletin de salaire privé / public du mois " +Hermes::HousingRequestFolder.new.get_month_label(-2)+" ou Attestation de l'employeur",
                             "Bulletin de salaire privé / public du mois " +Hermes::HousingRequestFolder.new.get_month_label(-3)+" ou Attestation de l'employeur",],
        r_for_consultation: true,
        r_for_application: true
      }, {
        monthly_incomes: %w[SAL],
        work_contract_type: %w[ART],
        required_documents: ['Dernier bilan ou attestation du comptable de l\'entreprise évaluant le salaire mensuel perçu ou tout document comptable habituellement fourni à l\'administration permettant de justifier les revenus'],
        r_for_consultation: true,
        r_for_application: true
      }, {
        monthly_incomes: %w[AMV],
        required_documents: ['Notification de pension de minimum vieillesse'],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[PAR],
        required_documents: ['Extrait du jugement de divorce ou autre document démontrant la perception de la pension'],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[CHO],
        required_documents: ["Avis de paiement de l'ARE"],
        r_for_consultation: false,
        r_for_application: true
      }, {
        monthly_incomes: %w[
          AF
          AAH
          AEEH
          AJPP
          RSA
          PAJE
          PDA
        ],
        required_documents: ["Attestation de la Caisse d’allocations familiales (CAF) /Mutualité sociale agricole (MSA)"],
        r_for_consultation: false,
        r_for_application: true
      }
    ].each do |rule|
      rule[:monthly_incomes].each do |income|
        describe 'monthly_income= ' + income do
          before :each do
            income_hash = {}
            income_hash[income.to_s] = 200
            applicant1.nationality = nil
            applicant1.monthly_incomes = income_hash
            applicant1.monthly_charges = {
              'PAV' => ""
            }
            if rule[:work_contract_type]
              applicant1.work_contract_type = rule[:work_contract_type][0]
            end
            applicant1.save
          end
          it 'comute the required document' do
            expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_documents])).to eq(true)
          end
        end
        describe 'for 2nd applicant monthly_income= ' + income do
          before :each do
            income_hash = {}
            income_hash[income.to_s] = 200
            applicant1.nationality = nil
            applicant1.save
            housing_request1.coapplicants = [
              {rel_type: 'Conjoint (e)', id: applicant2.id}
            ]
            housing_request1.save
            housing_request1.reload
            applicant2.monthly_incomes = income_hash
            applicant2.nationality = nil
            if rule[:work_contract_type]
              applicant2.work_contract_type = rule[:work_contract_type][0]
            end
            applicant2.save
            housing_request1.reload
          end
          it 'comute the required document' do
            expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_documents])).to eq(true)
          end
        end
      end
    end
  end

  describe 'try to reproduce bug' do
    before :each do
      applicant1.nationality = nil
      applicant2.nationality = nil
      applicant1.save
      applicant2.save
      applicant1.reload
      applicant2.reload
      housing_request1.coapplicants = [
        {rel_type: 'Conjoint (e)', id: applicant2.id.to_s}
      ]
      housing_request1.save
      housing_request1.reload
      applicant2.family_situation = 'S'
      
      applicant2.save
      applicant2.family_situation = 'P'
      applicant2.save
      applicant1.family_situation = 'V'
      
      applicant1.save
    end
    it 'comute the required document' do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      expect(rd.writers).to eq([user2.id])
    end
    it "comute the required document" do
      applicant2.user_id = user3.id
      applicant2.save
      
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      
      expect(rd.writers).to eq([user2.id, user3.id])
    end
    it "destroy after applicant destroy" do
      applicant2.destroy
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
    end
  end
  describe 'actual_housing2' do
    [
      {
        actual_housing_detail: ['SLHT'],
        required_documents: ["(Vous êtes sous locataire)
(« Bail et dernière quittance de loyer ou attestation du bailleur indiquant que le locataire est à jour des loyers et charges ou tout moyen de preuve des paiements effectués. »

(Vous êtes hébergé dans un logement à titre temporaire)
« Attestation de la personne qui héberge »
"]
      }
    ].each do |rule|
      rule[:actual_housing_detail].each do |actual_housing_detail|
        describe 'actual_housing_detail= ' + actual_housing_detail do
          before :each do
            applicant1.nationality = nil
            housing_request1.housing_type_list = [actual_housing_detail]
            housing_request1.save
            applicant1.save
          end
          it 'comute the required document' do
expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_documents])).to eq(true)
          end
        end
      end
    end
  end
  describe 'actual_housing' do
    [
      {
        actual_housing_detail: %w[POCC],
        required_documents: ['Acte de propriété', 'Plan de financement']
      }, {
        actual_housing_detail: %w[RSLL RHVS HSH HCDFCM RE],
        required_documents: ['Attestation de la structure d’hébergement ou du gestionnaire du logement-foyer']
      }, {
        actual_housing_detail: %w[FONC],
        required_documents: ["Contrat de bail","Quittance de loyer ou attestation du bailleur indiquant que vous êtes à jour de vos loyers et charges, ou tout moyen de preuve des paiements effectués"]
      }, {
        actual_housing_detail: %w[HCPE HCP],
        required_documents: ['Attestation de la personne qui héberge']
      }, {
        actual_housing_detail: %w[SD CAMCAR HHOT HABMOB],
        required_documents: ["Attestation d’un travailleur social, d’une association ou certificat de domiciliation"]
      }, {
        actual_housing_detail: %w[HLM LP],
        required_documents: ["Contrat de bail","Quittance de loyer ou attestation du bailleur indiquant que vous êtes à jour de vos loyers et charges, ou tout moyen de preuve des paiements effectués"]
    }
    ].each do |rule|
      rule[:actual_housing_detail].each do |actual_housing_detail|
        describe 'actual_housing_detail= ' + actual_housing_detail do
          before :each do
            applicant1.nationality = nil
            housing_request1.housing_type_list = [actual_housing_detail]
            housing_request1.save
            applicant1.save
          end
          it 'comute the required document' do
            expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_documents])).to eq(true)
          end
        end
      end
    end
  end
  describe 'family_situation' do
    [{
       situation: 'P',
       required_document: "Attestation d'enregistrement de PACS"
     }, {
       situation: 'M',
       required_document: 'Livret de famille ou tout document équivalant démontrant le mariage'
     }, {
       situation: 'D',
       required_document: "Jugement de divorce ou convention homologuée en cas de divorce par consentement mutuel"
     }, {
       situation: 'S',
       required_document: "Jugement de divorce ou convention homologuée en cas de divorce par consentement mutuel 
ou
Mention de dissolution du pacs dans l'acte de naissance
ou
Séparation d'un couple pacsé récépissé d'enregistrement de la déclaration
ou
Ordonnance de non-conciliation ou, à défaut, copie de l’acte de saisine du juge aux affaires familiales dans les conditions prévues au code de procédure civile ou, lorsque c’est un divorce par consentement mutuel, justificatif de l’avocat du demandeur"
     }, {
       situation: 'V',
       required_document: 'Certificat de décès ou livret de famille'
     }].each do |rule|
      describe 'family_situation= ' + rule[:situation] do
        before :each do
          applicant1.nationality = nil
          applicant1.family_situation = rule[:situation]
          applicant1.save
        end
        it 'comute the required document' do
          expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_document])).to eq(true)
        end
      end
    end
  end
  describe 'ressources' do
    [{
      required_document: "Avis d'imposition "+ ((Date.current - 1.years).year.to_s )+" sur les revenus de l'année " + ((Date.current - 2.years).year.to_s )
      }, {
       required_document: "Avis d'imposition "+ ((Date.current - 0.years).year.to_s )+" sur les revenus de l'année " + ((Date.current - 1.years).year.to_s )
     }].each_with_index do |rule, i|
      describe 'amount_year_minus = ' + i.to_s do
        before :each do
          applicant1.nationality = nil
          
          if i == 1
            applicant1.amount_year_minus_one = 2222
          else
            applicant1.amount_year_minus_two = 2222
          end
          
          applicant1.save
        end
        it 'comute the required document' do
          expect(housing_request1.reload.housing_request_folder.types_include(rule[:required_document])).to eq(true)
        end
      end
    end
  end
  describe 'family_situation' do
    [{
       situation: 'P',
       required_document: "Attestation d'enregistrement de PACS"
     }, {
       situation: 'M',
       required_document: 'Livret de famille ou tout document équivalant démontrant le mariage'
     }, {
       situation: 'D',
       required_document: "Jugement de divorce ou convention homologuée en cas de divorce par consentement mutuel"
     }, {
       situation: 'S',
       required_document: "Jugement de divorce ou convention homologuée en cas de divorce par consentement mutuel 
ou
Mention de dissolution du pacs dans l'acte de naissance
ou
Séparation d'un couple pacsé récépissé d'enregistrement de la déclaration
ou
Ordonnance de non-conciliation ou, à défaut, copie de l’acte de saisine du juge aux affaires familiales dans les conditions prévues au code de procédure civile ou, lorsque c’est un divorce par consentement mutuel, justificatif de l’avocat du demandeur"
     }, {
       situation: 'V',
       required_document: 'Certificat de décès ou livret de famille'
     }].each do |rule|
      describe 'family_situation= ' + rule[:situation] do
        before :each do
          applicant2.nationality = nil
          applicant2.family_situation = rule[:situation]
          applicant2.save
          housing_request1.coapplicants = [
            {rel_type: 'Conjoint (e)', id: applicant2.id}
          ]
          housing_request1.save
          housing_request1.reload
        end
        it 'comute the required document' do
          expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
          types = housing_request1.reload.housing_request_folder.required_documents.pluck(:type)
          expect(types.include?(rule[:required_document])).to eq(true)
        end
      end
    end
  end
  describe 'ressources' do
    [{
      required_document: "Avis d'imposition "+ ((Date.current - 1.years).year.to_s )+" sur les revenus de l'année " + ((Date.current - 2.years).year.to_s )
      }, {
      required_document: "Avis d'imposition "+ ((Date.current - 0.years).year.to_s )+" sur les revenus de l'année " + ((Date.current - 1.years).year.to_s )
     }].each_with_index do |rule, i|
      describe 'amount_year_minus = ' + i.to_s do
        before :each do
          applicant1.nationality = nil
          
          if i == 1
            applicant2.amount_year_minus_one = 2222
          else
            applicant2.amount_year_minus_two = 2222
          end
          
          applicant2.save
          housing_request1.coapplicants = [
            {rel_type: 'Conjoint (e)', id: applicant2.id}
          ]
          housing_request1.save
          housing_request1.reload
        end
        it 'comute the required document' do
          types = housing_request1.reload.housing_request_folder.required_documents.pluck(:type)
          expect(types.include?(rule[:required_document])).to eq(true)
        end
      end
    end
  end
  describe 'motivation' do
    [{
       motivation: '08',
       required_document: 'Certificat médical'
     }, {
       motivation: '28',
       required_document: "Attestation de l'employeur actuel ou futur justifiant votre mobilité professionnelle"
     }, {
       motivation: '15',
       required_document: 'Attestation de dépôt de demande de regroupement familial'
     }, {
       motivation: '02',
       required_document: 'Toute pièce établissant de la démolition de votre logement actuel'
     }, {
       motivation: '07',
       required_document: "Carte d’invalidité ou décision d’une commission administrative compétente (commissions des droits et de l’autonomie des personnes handicapées) ou d’un organisme de sécurité sociale"
     }, {
       motivation: '05',
       required_document: "Commandement de payer ou assignation à comparaître ou jugement prononçant l’expulsion ou commandement de quitter les lieux"
     }, {
       motivation: '22',
       required_document: "Plan d'apurement de la dette ou démarches en cours attestées par un travailleur social ou une association ou autre document démontrant les difficultés"
     }, {
       motivation: '26',
       required_document: 'Agrément assistant(e) maternel(le)'
     }, {
       motivation: '06',
       required_document: "Décision du juge prise en application de l'article 257 du code civil attestant de la situation d'urgence ou ordonnance de protection délivrée par le juge aux affaires familiales ou récépissé de dépôt de plainte"   }, {
       motivation: '04',
       required_document: 'Lettre de congé du propriétaire ou jugement prononçant la résiliation du bail'
     }, {
       motivation: '24',
       required_document: "Document établi par un service public, un travailleur social, un professionnel du bâtiment ou une association ayant pour objet l'insertion ou le logement ou copie du jugement d'un tribunal statuant sur l'indécence du logement ou attestation de la CAF/MSA ou autre document démontrant l'indécence du logement"
     }, {motivation: '25',
         required_document: "Logement insalubre ou dangereux :
Document établi par un service public, un travailleur social, un professionnel du bâtiment ou une association ayant pour objet l'insertion ou le logement, photos, jugement du tribunal, attestation de la CAF ou de la CMSA, copie d'une décision de l'administration (mise en demeure, arrêté préfectoral ou municipal d'insalubrité remédiable ou irrémédiable ou de péril, ou de fermeture administrative s'il s'agit d'un hôtel meublé) ou autre document démontrant l'insalubrité ou la dangerosité du logement ou de l'immeuble
Logement impropre à l'habitation :
Document établi par un service public, un travailleur social, un professionnel du bâtiment ou une association ayant pour objet l'insertion ou le logement, photos, jugement du tribunal, arrêté préfectoral de mise en demeure de faire cesser l'occupation des lieux ou autre document démontrant le caractère impropre à l'habitation"}].each do |rule|
      describe 'motivation= ' + rule[:motivation] do
        before :each do
          applicant1.nationality = nil
          
          applicant1.save
          housing_request1.reload
          housing_request1.motivation1 = rule[:motivation]
          housing_request1.save
        end
        it 'comute the required document' do
          expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
          rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[2])
          expect(rd.type).to eq(rule[:required_document])
        end
      end
    end
  end

  describe 'get file list from sne' do
    let!(:nud1) do
      create(
        :nud,
        housing_request: housing_request1,
        department: '12',
        creation_date: '2016-23-14T14:53:22',
        unique_number: '0130719003149G3U05'
      )
    end
    before :each do
    end
    it 'comute the required document' do
      VCR.use_cassette("syncro_files_from_sne2", :match_requests_on => [:method, :uri, :path]) do
  
  
        end
    end
  end 

  describe 'get files from sne' do
    let!(:nud1) do
      create(
        :nud,
        housing_request: housing_request1,
        department: '12',
        creation_date: '2016-23-14T14:53:22',
        unique_number: '0130719003149G3U05'
      )
    end
    before :each do
      income_hash = {}
      #income_hash['SAL'] = 200
      applicant1.nationality = 1
      #applicant1.monthly_incomes = income_hash
     # applicant1.work_contract_type = 'APP'
      applicant1.save
      VCR.use_cassette("syncro_files_from_sne3", :match_requests_on => [:method, :uri, :path]) do

      housing_request1.reload.housing_request_folder.syncro_files_from_sne('0130719003149G3U05')
        end
    end
    it 'go found the goods documents in the sne' do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(3)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      res = []
      expect(rd.reload.doc_id).not_to be nil
      
    end

    it 'should update folders cache keys when destroy required_document' do
      folder = housing_request1.reload.housing_request_folder
      before_destroy_value = folder.updated_at.to_i
      expect(folder.required_document_ids.length).to eq(3)
      rd = Hermes::RequiredDocument.find(folder.required_document_ids[0])
      sleep 1
      rd.destroy
      after_destroy_value = folder.reload.updated_at.to_i
      expect(before_destroy_value).not_to eq(after_destroy_value)
    end
  end
end
